# this script  is install by unitrends-elk rpm and it is added to crontab to run once a day to check if asset should be enable to send logs to ELK
# Author: <agonzalez@unitrends.com>

export PATH=/usr/local/pgsql/bin:/sbin:/usr/sbin:/bin:/usr/bin:/bin:/usr/local/bin:/usr/bp/bin:/usr/bp/lib/shlib

function retry()
{
        local n=0
        $@
        while [ $? -ne 0 -a $n -lt 5 ]
        do
                sleep 2
                ((n++))
                echo "retying $n"
                $@
        done
}

start() {
        if [ -f /usr/bp/bin/elk/elk.disabled ]
        then
                echo
                echo "[DISABLED] - ELK is disabled, run /usr/bp/bin/elk/elk.sh enable to enable it again."
                return
        fi

        echo "[*] Adding ELK as SNMP target..."
        echo '{"destination":"ls.telemetry.unitrends.com","enabled":1}'|curl -s -d @- http://localhost/api/traps/destinations/?sid=1

        echo "[*] Enabling elkcollect schedule..."
        ( crontab -l | grep -v "elkcollect.exe" | grep -v "elkagent" ) | grep -v "elk.sh" |crontab -

         /bin/cp -f /usr/bp/bin/elk/elkcollect.cron /etc/cron.d/unitrends-elkcollect
	 #/bin/cp -f /usr/bp/bin/elk/elkagent.cron /etc/cron.d/unitrends-elkagent
         /bin/cp -f /usr/bp/bin/elk/elk.cron /etc/cron.d/unitrends-elk

         # Enable triggers
        psql bpdb postgres -c "ALTER TABLE bp.jobs ENABLE TRIGGER elk_job_finished" > /dev/null 2>&1
        psql bpdb postgres -c "ALTER TABLE bp.alerts ENABLE TRIGGER elk_alert" > /dev/null 2>&1
}

stop() {
        crontab -l | grep -v "elkcollect.exe" | grep -v "elk.sh" | grep -v "elkagent" |crontab -
        rm -fr /etc/cron.d/unitrends-elkcollect
	rm -fr /etc/cron.d/unitrends-elkagent
        rm -fr /etc/cron.d/unitrends-elk
        psql bpdb postgres -c "ALTER TABLE bp.jobs DISABLE TRIGGER elk_job_finished" > /dev/null 2>&1
        psql bpdb postgres -c "ALTER TABLE bp.alerts DISABLE TRIGGER elk_alert" > /dev/null 2>&1
        /etc/init.d/filebeat stop 2> /dev/null
        /etc/init.d/metricbeat stop 2> /dev/null
        /sbin/chkconfig --del filebeat
        /sbin/chkconfig --del metricbeat
        rm -fr /var/lib/filebeat/registry
}

disable() {
        stop
        touch /usr/bp/bin/elk/elk.disabled
        echo "[DISABLED] - ELK has been disabled."
}

status() {
        if [ -f /usr/bp/bin/elk/elk.disabled ]
        then
                echo "[DISABLED] - ELK is disabled."
        else
                echo "[ENABLED] - ELK is enabled."
        fi
}

enable() {
        start
        rm -fr /usr/bp/bin/elk/elk.disabled
}

update()
{
	/usr/bin/docker rm $(/usr/bin/docker ps -a -q -f status=exited)
	/usr/bin/docker rmi -f $(/usr/bin/docker images -f "dangling=true" -q)	
	k=$(cat /etc/redhat-release  | awk '{ print $3 }' | cut -f1 -d'.')
	echo $k
	if [[ $k == 6 ]]
	then
		/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_6 -t unitrends/py3 /usr/bp/bin/elk/
        	/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_6_1 -t elkagent /usr/bp/bin/elk/
		mount -o rw,remount /sys
	elif [[ $k == 7 ]]
	then
		/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_7 -t elkagent /usr/bp/bin/elk/
	fi

	PROTO=$(/usr/local/bin/dpu repo proto)
        TARGET=$(/usr/local/bin/dpu repo target)
        VERSION_FILE="$PROTO://$TARGET/dpu/elk/version.txt"
        ELK_FILE="$PROTO://$TARGET/dpu/elk/unitrends-elk-bin.zip"

        echo "[*] Checking for new version ($VERSION_FILE)..."
        retry curl -H 'Cache-Control: no-cache' -s $VERSION_FILE -o /tmp/elk_latest_version
        if [ ! -f  /tmp/elk_latest_version ]
        then
                echo "[ERROR] Cant find remote version ($VERSION_FILE)"
                exit 1
        fi

        remote_version=`cat /tmp/elk_latest_version 2>/dev/null`       
        rm -fr /tmp/elk_latest_version

        local_version=`mono /usr/bp/bin/elk/elkcollect.exe version`
        
        if [ $? -ne 0 ]
        then
                local_version="unknown"
                local_version_n=0
        else
                local_version_n=`echo $local_version|tr -d .`
        fi

        if [ -z "$remote_version" ]
        then
                echo "  - ERROR. Cant get remote version from repo."
                exit 1
        else
                remote_version_n=`echo $remote_version|tr -d .`
        fi

        echo "  - Installed: $local_version ($local_version_n) / Remote: $remote_version ($remote_version_n)"
        
        if [ $local_version_n -lt $remote_version_n ]
        then
                echo "  - New version found:"
                echo "    - Installed: $local_version"
                echo "    - Available: $remote_version"

                retry curl -H 'Cache-Control: no-cache' -s $ELK_FILE -o /tmp/unitrends-elk-bin.zip
                unzip -t /tmp/unitrends-elk-bin.zip
                if [ $? -ne 0 ]
                then
                        echo "[ERROR] Cant find remote file ($ZIP_FILE) or unzip file /tmp/unitrends-elk-bin.zip"
                        exit 1
                fi

                echo "  - Extracting ..."
                unzip -o /tmp/unitrends-elk-bin.zip -d /usr/bp/bin/elk/
                rm -fr /tmp/unitrends-elk-bin.zip
		k=$(cat /etc/redhat-release | awk '{ print $3 }' | cut -f1 -d'.')
		echo $k
		if [[ $k == 6 ]]
		then
			echo "Restarting Docker"
			service docker restart
			rm -f /usr/bp/bin/elk/Dockerfile_7
			rm -f /usr/bp/bin/elk/elkagent.cron
			/bin/cp -f /usr/bp/bin/elk/elkagent_6.cron /etc/cron.d/unitrends-elkagent_6
			/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_6 -t unitrends/py3 /usr/bp/bin/elk/
			/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_6_1 -t elkagent /usr/bp/bin/elk/
		elif [[ $k == 7 ]]
		then
			rm -f /usr/bp/bin/elk/Dockerfile_6
			rm -f /usr/bp/bin/elk/Dockerfile_6_1
			rm -f /usr/bp/bin/elk/elkagent_6.cron
			rm -f /usr/bp/bin/elk/Cent6_Docker_Fix.sh
			/bin/cp -f /usr/bp/bin/elk/elkagent.cron /etc/cron.d/unitrends-elkagent
			/usr/bin/docker build -f /usr/bp/bin/elk/Dockerfile_7 -t elkagent /usr/bp/bin/elk/
		fi
                chmod a+x /usr/bp/bin/elk/elkcollect.exe
                chmod a+x /usr/bp/bin/elk/elk.sh
                chmod a+x /usr/bp/bin/elk/elk_job_trigger.sh
                chmod a+x /usr/bp/bin/elk/elk_alert_trigger.sh
		chmod a+x /usr/bp/bin/elk/elk_default.py
		chmod a+x /usr/bp/bin/elk/collectors.py
		#/usr/bin/docker build -t elkagent /usr/bp/bin/elk/

                /bin/cp -f /usr/bp/bin/elk/elkcollect.cron /etc/cron.d/unitrends-elkcollect
                /bin/cp -f /usr/bp/bin/elk/elk.cron /etc/cron.d/unitrends-elk
        fi
}


run_script()
{
        return
        echo "[*] Running script..."
        /usr/local/bin/dpu version|grep "10."
        if [ $? -eq 0 ]
        then
                if [ -f /usr/bp/bin/elk/jobs-status-from-ID.php ]
                then
                        echo "  - Replacing jobs-status-from-ID.php"
                        cp -fr /usr/bp/bin/elk/jobs-status-from-ID.php /var/www/html/api/includes/jobs/jobs-status-from-ID.php
                fi
        fi
}

delay()
{
        echo ""
        echo "===[ `date`] ============================================================="
        i=$(( ( RANDOM % 1200 )  + 1 ))
        echo "[*] Waiting $i seconds ..."
        sleep $i
}


if [ ! -d /var/log/elk ]
then 
        mkdir /var/log/elk
        chown postgres:postgres /var/log/elk
fi

IFS=
BASEURL="http://api.telemetry.unitrends.com/"
URL="http://api.telemetry.unitrends.com/api/asset/"
ASSET_TAG=`cat /etc/unitrends-asset 2>/dev/null`
croncmd="mono /usr/bp/bin/elk/elkcollect.exe &>> /var/log/unitrends-elkcollect.log"
croncmd2="mono /usr/bp/bin/elk/elkcollect.exe level1 &>> /var/log/unitrends-elkcollect.log"
cronjob="55 23 * * * $croncmd"
cronjob2="0 */4 * * * $croncmd2"

# kill existing elkcollect in case it hung
pgrep elkcollect.exe 2>/dev/null|xargs kill -9 2>/dev/null

# remove elkcollect.lock in case it hung
rm -fr /tmp/elkcollect.lock

# purge logs
log_size=$(du -sb /var/log/unitrends-elk.log 2>/dev/null | awk 'END { if (!NR) {print "0"} else {print $1} }')
if [ "$log_size" -gt 300000 ]
then
        echo > /var/log/unitrends-elk.log
        echo "elk log purged"
fi

log_size=$(du -sb /var/log/unitrends-elkcollect.log 2>/dev/null | awk 'END { if (!NR) {print "0"} else {print $1} }')
if [ "$log_size" -gt 300000 ]
then
        echo > /var/log/unitrends-elkcollect.log
        echo "elk-collect purged"
fi

log_size=$(du -sb /var/log/unitrends-elkagent.log 2>/dev/null | awk 'END { if (!NR) {print "0"} else {print $1} }')
if [ "$log_size" -gt 300000 ]
then
        echo > /var/log/unitrends-elkagent.log
        echo "elk log purged"
fi




# kill existing elkcollect in case it hung
pgrep elkcollect.exe 2>/dev/null|xargs kill -9 2>/dev/null

case "$1" in
        start)
                start
        ;;
        stop)
                stop
        ;;
        update)
                update
        ;;
        delay)
                delay
                update
                run_script
        ;;
        disable)
                disable
        ;;
        enable)
                enable
        ;;
        status)
                status
        ;;
        *)
                update
                run_script
        ;;
esac
