#!/bin/bash

ERRORLOG="/var/log/elk/elk-alert-trigger.log"
LASTCOMMANDLOG="/var/log/elk/elk-last-alert-command.log"

export PATH=/usr/local/pgsql/bin:/sbin:/usr/sbin:/bin:/usr/bin:/bin:/usr/local/bin:/usr/bp/bin:/usr/bp/lib/shlib

lockfile -r 20 /tmp/elkcollect.lock
if [ $? -ne 0 ]; then
        echo "[ERROR] Cant acquire lockfile /tmp/elkcollect.lock" >> $ERRORLOG
        exit 1
fi


ASSET=$(cat /etc/unitrends-asset)
dt=`date`
if [ -f $ERRORLOG ]; then
	log_size=$(du -sb $ERRORLOG | awk '{print $1}')
	if [ $log_size -gt 2000000 ]; then
		echo > $ERRORLOG
		echo -e "$dt: logfile rolled-over"
	fi
fi

while getopts "i:m:c:u:n:s:r:" flag
do
	case $flag in
		i) ALERTID=${OPTARG};;
		m) MESSAGE=${OPTARG};;
		c) CREATED=${OPTARG};;
		u) UPDATED=${OPTARG};;
		n) SID=${OPTARG};;
		s) SEVERITY=${OPTARG};;
		r) RESOLVED=${OPTARG};;
	esac
done

# Convert source_id to name
SNAME=`psql bpdb postgres -tc "select source_name from bp.alert_source where source_id = $SID" 2>>$ERRORLOG | tr -d '[:space:]'` 

# Convert severity to string
case $SEVERITY in
	1) SEVERITY="critical";;
	2) SEVERITY="warning";;
	3) SEVERITY="notice";;
esac

if [ "$RESOLVED" == "t" ]; then
	RESOLVED="true"
else
	RESOLVED="false"
fi

index="ueb-alerts-$(date +%Y.%m)"
CREATED_STR=$(date -d@$CREATED +'%d/%m/%Y %r')
UPDATED_STR=$(date -d@$UPDATED +'%d/%m/%Y %r')
TIMESTAMP=$(date --rfc-3339=seconds|tr ' ' 'T')

JSON='{"trigger":"alert","created":'\"$CREATED_STR\"',"id":'$ALERTID',"message":'\"$MESSAGE\"',"resolved":'"$RESOLVED"',"severity":'\"$SEVERITY\"',"source_name":'\"$SNAME\"',"updated":'\"$UPDATED_STR\"',"timestamp":'\"$TIMESTAMP\"',"asset_tag":'\"$ASSET\"'}'

# use elkcollect for dev/prod enviroment
#echo $JSON|curl -k -XPOST https://unitrends:pass@es.telemetry.unitrends.com/$index/alert/$ASSET"_"$ALERTID/?pretty -H 'Content-Type: application/json' -d @- >/dev/null 2>&1
#if [ $? -ne 0 ]; then
#        echo -e "${dt}: Command Failed! $JSON" >> $ERRORLOG
#fi

output=`mono /usr/bp/bin/elk/elkcollect.exe trigger "$JSON"`
if [ $? -ne 0 ]; then
        echo -e "${dt}: Command Failed! mono /usr/bp/bin/elk/elkcollect.exe trigger $JSON" >> $ERRORLOG
    echo -e "$output" >> $ERRORLOG
fi

echo -e "${dt}: mono /usr/bp/bin/elk/elkcollect.exe trigger $JSON" > $LASTCOMMANDLOG
echo -e "$output" >> $LASTCOMMANDLOG

rm -fr /tmp/elkcollect.lock
