#!/bin/bash

ERRORLOG="/var/log/elk/elk-job-trigger.log"
LASTCOMMANDLOG="/var/log/elk/elk-last-job-command.log"

export PATH=/usr/local/pgsql/bin:/sbin:/usr/sbin:/bin:/usr/bin:/bin:/usr/local/bin:/usr/bp/bin:/usr/bp/lib/shlib

ASSET=$(cat /etc/unitrends-asset)
dt=`date`
if [ -f $ERRORLOG ]; then
	log_size=$(du -sb $ERRORLOG | awk '{print $1}')
	if [ $log_size -gt 2000000 ]; then
		echo > $ERRORLOG
		echo -e "$dt: logfile rolled-over"
	fi
fi

while getopts "s:i:t:e:b:f:p:" flag
do
	case $flag in
		s) SYSID=${OPTARG};;
		i) INSTID=${OPTARG};;
		t) if [[ ${OPTARG} == " -z"* ]];then TYPE="archive";else TYPE="backup";fi;;
		e) STARTTIME=${OPTARG};;
		b) BACKUPID=${OPTARG};;
		f) LOGFILE=${OPTARG};;
		p) PID=${OPTARG};;
	esac
done

if [ "$BACKUPID" == "" ]; then
	echo -e "No backup Id" >> $ERRORLOG
	exit
fi

STARTIME=`psql bpdb postgres -tAc "select queued_date from bp.jobs where pid = $PID"`

if [ "$TYPE" == "archive" ]; then
	BACKUPID=`psql bpdb postgres -tc "select archive_set_id from bp.archive_sets where pid = $PID order by archive_set_id desc limit 1" | awk 'NR==1{print $1}'`
	STARTTIME=`psql bpdb postgres -tc "select creation_timestamp from bp.archive_sets where archive_set_id = $BACKUPID order by creation_timestamp desc limit 1" | awk 'NR==1{print $1}'`
	archives=`psql bpdb postgres -tAc "select archive_id from bp.archives where archive_set_id = $BACKUPID order by archive_id"`
	for arch in $archives; do
		output=`mono /usr/bp/bin/elk/elkcollect.exe trigger '{"trigger":"job","asset_tag":"'"$ASSET"'","sys_id":"'$SYSID'","backup_id":"'$arch'","type":"'$TYPE'","start_time":"'$STARTTIME'","instance_id":"'$INSTID'","log_file":"/usr/bp/logs.dir/'$LOGFILE'"}'`
		if [ $? -ne 0 ]; then
			echo -e "${dt}: Command Failed! mono /usr/bp/bin/elk/elkcollect.exe trigger '{\"trigger\":\"job\",\"asset_tag\":\"$ASSET\",\"sys_id\":\"$SYSID\",\"backup_id\":\"$arch\",\"type\":\"$TYPE\",\"start_time\":\"$STARTTIME\",\"instance_id\":\"$INSTID\",\"log_file\":\"/usr/bp/logs.dir/$LOGFILE\"}'" >> $ERRORLOG
			echo -e "$output" >> $ERRORLOG
		fi
		echo -e "${dt}: mono /usr/bp/bin/elk/elkcollect.exe trigger '{\"trigger\":\"job\",\"asset_tag\":\"$ASSET\",\"sys_id\":\"$SYSID\",\"backup_id\":\"$arch\",\"type\":\"$TYPE\",\"start_time\":\"$STARTTIME\",\"instance_id\":\"$INSTID\",\"log_file\":\"/usr/bp/logs.dir/$LOGFILE\"}'" > $LASTCOMMANDLOG
		echo -e "$output" >> $LASTCOMMANDLOG
	done
else
	output=`mono /usr/bp/bin/elk/elkcollect.exe trigger '{"trigger":"job","asset_tag":"'"$ASSET"'","sys_id":"'$SYSID'","backup_id":"'$BACKUPID'","type":"'$TYPE'","start_time":"'$STARTTIME'","instance_id":"'$INSTID'","log_file":"/usr/bp/logs.dir/'$LOGFILE'"}'`
	if [ $? -ne 0 ]; then
		echo -e "${dt}: Command Failed! mono /usr/bp/bin/elk/elkcollect.exe trigger '{\"trigger\":\"job\",\"asset_tag\":\"$ASSET\",\"sys_id\":\"$SYSID\",\"backup_id\":\"$BACKUPID\",\"type\":\"$TYPE\",\"start_time\":\"$STARTTIME\",\"instance_id\":\"$INSTID\",\"log_file\":\"/usr/bp/logs.dir/$LOGFILE\"}'" >> $ERRORLOG
		echo -e "$output" >> $ERRORLOG
	fi
	echo -e "${dt}: mono /usr/bp/bin/elk/elkcollect.exe trigger '{\"trigger\":\"job\",\"asset_tag\":\"$ASSET\",\"sys_id\":\"$SYSID\",\"backup_id\":\"$BACKUPID\",\"type\":\"$TYPE\",\"start_time\":\"$STARTTIME\",\"instance_id\":\"$INSTID\",\"log_file\":\"/usr/bp/logs.dir/$LOGFILE\"}'" > $LASTCOMMANDLOG
	echo -e "$output" >> $LASTCOMMANDLOG
fi
